package com.zhyc.module.feed.service;

import java.util.List;
import com.zhyc.module.feed.domain.SgFormulaManagement;

/**
 * 配方管理Service接口
 * 
 * @author HashMap
 * @date 2025-08-09
 */
public interface ISgFormulaManagementService 
{
    /**
     * 查询配方管理
     * 
     * @param formulaId 配方管理主键
     * @return 配方管理
     */
    SgFormulaManagement selectSgFormulaManagementByFormulaId(String formulaId);

    /**
     * 查询配方管理列表
     * 
     * @param sgFormulaManagement 配方管理
     * @return 配方管理集合
     */
    List<SgFormulaManagement> selectSgFormulaManagementList(SgFormulaManagement sgFormulaManagement);

    /**
     * 新增配方管理
     * 
     * @param sgFormulaManagement 配方管理
     * @return 结果
     */
    int insertSgFormulaManagement(SgFormulaManagement sgFormulaManagement);

    /**
     * 修改配方管理
     * 
     * @param sgFormulaManagement 配方管理
     * @return 结果
     */
    int updateSgFormulaManagement(SgFormulaManagement sgFormulaManagement);

    /**
     * 批量删除配方管理
     * 
     * @param formulaIds 需要删除的配方管理主键集合
     * @return 结果
     */
    int deleteSgFormulaManagementByFormulaIds(String[] formulaIds);

    /**
     * 删除配方管理信息
     * 
     * @param formulaId 配方管理主键
     * @return 结果
     */
    int deleteSgFormulaManagementByFormulaId(String formulaId);

    /***
     * 删除配方管理信息
     */
    int deleteSgFormulaManagement(SgFormulaManagement sgFormulaManagement);
}
